diff --git a/htdocs/admin/system/perf.php b/htdocs/admin/system/perf.php
index 8cc7532b647..7a34b584499 100644
--- a/htdocs/admin/system/perf.php
+++ b/htdocs/admin/system/perf.php
@@ -77,7 +77,11 @@ $test = empty($conf->syslog->enabled);
if ($test) {
print img_picto('', 'tick.png').' '.$langs->trans("NotInstalled").' - '.$langs->trans("NotSlowedDownByThis");
} else {
- print img_picto('', 'warning').' '.$langs->trans("ModuleActivated", $langs->transnoentities("Syslog"));
+ if ($conf->global->SYSLOG_LEVEL > LOG_NOTICE) {
+ print img_picto('', 'warning').' '.$langs->trans("ModuleActivatedWithTooHighLogLevel", $langs->transnoentities("Syslog"));
+ } else {
+ print img_picto('', 'tick.png').' '.$langs->trans("ModuleSyslogActivatedButLevelNotTooVerbose", $langs->transnoentities("Syslog"), $conf->global->SYSLOG_LEVEL);
+ }
//print ' '.$langs->trans("MoreInformation").' XDebug admin page';
}
print '
';
diff --git a/htdocs/langs/en_US/admin.lang b/htdocs/langs/en_US/admin.lang
index 5d78f312917..0bc0261e373 100644
--- a/htdocs/langs/en_US/admin.lang
+++ b/htdocs/langs/en_US/admin.lang
@@ -2061,9 +2061,11 @@ UseDebugBar=Use the debug bar
DEBUGBAR_LOGS_LINES_NUMBER=Number of last log lines to keep in console
WarningValueHigherSlowsDramaticalyOutput=Warning, higher values slows dramaticaly output
ModuleActivated=Module %s is activated and slows the interface
+ModuleActivatedWithTooHighLogLevel=Module %s is activated with a too high logging level (try to use a lower level for better performances)
ModuleSyslogActivatedButLevelNotTooVerbose=Module %s is activated and log level (%s) is correct (not too verbose)
IfYouAreOnAProductionSetThis=If you are on a production environment, you should set this property to %s.
AntivirusEnabledOnUpload=Antivirus enabled on uploaded files
+SomeFilesOrDirInRootAreWritable=Some files or directories are not in a read-only mode
EXPORTS_SHARE_MODELS=Export models are share with everybody
ExportSetup=Setup of module Export
ImportSetup=Setup of module Import
diff --git a/htdocs/langs/en_US/bills.lang b/htdocs/langs/en_US/bills.lang
index ad1d7f138e5..c0eb886a987 100644
--- a/htdocs/langs/en_US/bills.lang
+++ b/htdocs/langs/en_US/bills.lang
@@ -520,10 +520,10 @@ YouMustCreateStandardInvoiceFirstDesc=You have to create a standard invoice firs
PDFCrabeDescription=Invoice PDF template Crabe. A complete invoice template (old implementation of Sponge template)
PDFSpongeDescription=Invoice PDF template Sponge. A complete invoice template
PDFCrevetteDescription=Invoice PDF template Crevette. A complete invoice template for situation invoices
-TerreNumRefModelDesc1=Return number with format %syymm-nnnn for standard invoices and %syymm-nnnn for credit notes where yy is year, mm is month and nnnn is a sequence with no break and no return to 0
-MarsNumRefModelDesc1=Return number with format %syymm-nnnn for standard invoices, %syymm-nnnn for replacement invoices, %syymm-nnnn for down payment invoices and %syymm-nnnn for credit notes where yy is year, mm is month and nnnn is a sequence with no break and no return to 0
+TerreNumRefModelDesc1=Return number in the format %syymm-nnnn for standard invoices and %syymm-nnnn for credit notes where yy is year, mm is month and nnnn is a sequencial auto-incrementing number with no break and no return to 0
+MarsNumRefModelDesc1=Return number in the format %syymm-nnnn for standard invoices, %syymm-nnnn for replacement invoices, %syymm-nnnn for down payment invoices and %syymm-nnnn for credit notes where yy is year, mm is month and nnnn is a sequencial auto-incrementing number with no break and no return to 0
TerreNumRefModelError=A bill starting with $syymm already exists and is not compatible with this model of sequence. Remove it or rename it to activate this module.
-CactusNumRefModelDesc1=Return number with format %syymm-nnnn for standard invoices, %syymm-nnnn for credit notes and %syymm-nnnn for down payment invoices where yy is year, mm is month and nnnn is a sequence with no break and no return to 0
+CactusNumRefModelDesc1=Return number in the format %syymm-nnnn for standard invoices, %syymm-nnnn for credit notes and %syymm-nnnn for down payment invoices where yy is year, mm is month and nnnn is a sequencial auto-incrementing number with no break and no return to 0
EarlyClosingReason=Early closing reason
EarlyClosingComment=Early closing note
##### Types de contacts #####
diff --git a/htdocs/langs/en_US/categories.lang b/htdocs/langs/en_US/categories.lang
index 5ec33145da1..9520ef65a83 100644
--- a/htdocs/langs/en_US/categories.lang
+++ b/htdocs/langs/en_US/categories.lang
@@ -93,7 +93,7 @@ AddSupplierIntoCategory=Assign category to supplier
ShowCategory=Show tag/category
ByDefaultInList=By default in list
ChooseCategory=Choose category
-StocksCategoriesArea=Warehouses Categories
-ActionCommCategoriesArea=Events Categories
+StocksCategoriesArea=Warehouse Categories
+ActionCommCategoriesArea=Event Categories
WebsitePagesCategoriesArea=Page-Container Categories
UseOrOperatorForCategories=Use or operator for categories
diff --git a/htdocs/langs/en_US/companies.lang b/htdocs/langs/en_US/companies.lang
index 89463a535b3..b41bb49db13 100644
--- a/htdocs/langs/en_US/companies.lang
+++ b/htdocs/langs/en_US/companies.lang
@@ -449,7 +449,7 @@ CurrentOutstandingBill=Current outstanding bill
OutstandingBill=Max. for outstanding bill
OutstandingBillReached=Max. for outstanding bill reached
OrderMinAmount=Minimum amount for order
-MonkeyNumRefModelDesc=Return a number with the format %syymm-nnnn for the customer code and %syymm-nnnn for the vendor code where yy is year, mm is month and nnnn is a sequence with no break and no return to 0.
+MonkeyNumRefModelDesc=Return a number in the format %syymm-nnnn for the customer code and %syymm-nnnn for the vendor code where yy is year, mm is month and nnnn is a sequencial auto-incrementing number with no break and no return to 0.
LeopardNumRefModelDesc=The code is free. This code can be modified at any time.
ManagingDirectors=Manager(s) name (CEO, director, president...)
MergeOriginThirdparty=Duplicate third party (third party you want to delete)
diff --git a/htdocs/langs/en_US/compta.lang b/htdocs/langs/en_US/compta.lang
index 7080810bfea..926cda53c9f 100644
--- a/htdocs/langs/en_US/compta.lang
+++ b/htdocs/langs/en_US/compta.lang
@@ -231,7 +231,7 @@ Pcg_subtype=Pcg subtype
InvoiceLinesToDispatch=Invoice lines to dispatch
ByProductsAndServices=By product and service
RefExt=External ref
-ToCreateAPredefinedInvoice=To create a template invoice, create a standard invoice, then, without validating it, click onto button "%s".
+ToCreateAPredefinedInvoice=To create a template invoice, create a standard invoice, then, without validating it, click on button "%s".
LinkedOrder=Link to order
Mode1=Method 1
Mode2=Method 2
diff --git a/htdocs/langs/en_US/products.lang b/htdocs/langs/en_US/products.lang
index 9ec22ad00cc..28853762424 100644
--- a/htdocs/langs/en_US/products.lang
+++ b/htdocs/langs/en_US/products.lang
@@ -314,7 +314,7 @@ LastUpdated=Latest update
CorrectlyUpdated=Correctly updated
PropalMergePdfProductActualFile=Files use to add into PDF Azur are/is
PropalMergePdfProductChooseFile=Select PDF files
-IncludingProductWithTag=Including product/service with tag
+IncludingProductWithTag=Include products/services with tag
DefaultPriceRealPriceMayDependOnCustomer=Default price, real price may depend on customer
WarningSelectOneDocument=Please select at least one document
DefaultUnitToShow=Unit
diff --git a/htdocs/langs/en_US/stocks.lang b/htdocs/langs/en_US/stocks.lang
index eb238941eae..5f60715ae2a 100644
--- a/htdocs/langs/en_US/stocks.lang
+++ b/htdocs/langs/en_US/stocks.lang
@@ -19,8 +19,8 @@ Stock=Stock
Stocks=Stocks
MissingStocks=Missing stocks
StockAtDate=Stocks at date
-StockAtDateInPast=Date in past
-StockAtDateInFuture=Date in future
+StockAtDateInPast=Date in the past
+StockAtDateInFuture=Date in the future
StocksByLotSerial=Stocks by lot/serial
LotSerial=Lots/Serials
LotSerialList=List of lot/serials
@@ -37,8 +37,8 @@ AllWarehouses=All warehouses
IncludeEmptyDesiredStock=Include also negative stock with undefined desired stock
IncludeAlsoDraftOrders=Include also draft orders
Location=Location
-LocationSummary=Short name location
-NumberOfDifferentProducts=Number of different products
+LocationSummary=Short name of location
+NumberOfDifferentProducts=Number of unique products
NumberOfProducts=Total number of products
LastMovement=Latest movement
LastMovements=Latest movements
@@ -98,7 +98,7 @@ RealStockDesc=Physical/real stock is the stock currently in the warehouses.
RealStockWillAutomaticallyWhen=The real stock will be modified according to this rule (as defined in the Stock module):
VirtualStock=Virtual stock
VirtualStockAtDate=Virtual stock at date
-VirtualStockAtDateDesc=Virtual stock once all pending orders that are planned to be done before the date will be finished
+VirtualStockAtDateDesc=Virtual stock once all the pending orders that are planned to be processed before the chosen date will be finished
VirtualStockDesc=Virtual stock is the calculated stock available once all open/pending actions (that affect stocks) are closed (purchase orders received, sales orders shipped, manufacturing orders produced, etc)
AtDate=At date
IdWarehouse=Id warehouse
@@ -147,7 +147,7 @@ Replenishments=Replenishments
NbOfProductBeforePeriod=Quantity of product %s in stock before selected period (< %s)
NbOfProductAfterPeriod=Quantity of product %s in stock after selected period (> %s)
MassMovement=Mass movement
-SelectProductInAndOutWareHouse=Select a source warehouse and a target warehouse, a product and a quantity then click "%s". Once this is done for all required movements, click onto "%s".
+SelectProductInAndOutWareHouse=Select a source warehouse and a target warehouse, a product and a quantity then click "%s". Once this is done for all required movements, click on "%s".
RecordMovement=Record transfer
ReceivingForSameOrder=Receipts for this order
StockMovementRecorded=Stock movements recorded
@@ -238,7 +238,7 @@ StockIsRequiredToChooseWhichLotToUse=Stock is required to choose which lot to us
ForceTo=Force to
AlwaysShowFullArbo=Display full tree of warehouse on popup of warehouse links (Warning: This may decrease dramatically performances)
StockAtDatePastDesc=You can view here the stock (real stock) at a given date in the past
-StockAtDateFutureDesc=You can view here the stock (virtual stock) at a given date in future
+StockAtDateFutureDesc=You can view here the stock (virtual stock) at a given date in the future
CurrentStock=Current stock
InventoryRealQtyHelp=Set value to 0 to reset qty
Keep field empty, or remove line, to keep unchanged
UpdateByScaning=Fill real qty by scaning
diff --git a/htdocs/salaries/paiement_salary.php b/htdocs/salaries/paiement_salary.php
index 2f4a0c85905..5ab67c71c0e 100644
--- a/htdocs/salaries/paiement_salary.php
+++ b/htdocs/salaries/paiement_salary.php
@@ -29,7 +29,7 @@ require_once DOL_DOCUMENT_ROOT.'/salaries/class/paymentsalary.class.php';
require_once DOL_DOCUMENT_ROOT.'/compta/bank/class/account.class.php';
// Load translation files required by the page
-$langs->load("bills");
+$langs->loadLangs(array("banks", "bills"));
$action = GETPOST('action', 'alpha');
$cancel = GETPOST('cancel', 'alpha');
@@ -78,7 +78,7 @@ if ($action == 'add_payment' || ($action == 'confirm_paiement' && $confirm == 'y
$action = 'create';
}
if (!empty($conf->banque->enabled) && !(GETPOST("accountid", 'int') > 0)) {
- setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentities("AccountToCredit")), null, 'errors');
+ setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentities("AccountToDebit")), null, 'errors');
$error++;
$action = 'create';
}
@@ -223,6 +223,7 @@ if ($action == 'create') {
print ' ';
print '| '.$langs->trans('AccountToDebit').' | ';
print '';
+ print img_picto('', 'bank_account', 'class="pictofixedwidth"');
$form->select_comptes(GETPOSTISSET("accountid") ? GETPOST("accountid", 'int') : $salary->accountid, "accountid", 0, '', 1); // Show opend bank account list
print ' | ';
|
|
diff --git a/htdocs/salaries/card.php b/htdocs/salaries/card.php
index 323e2c74c5a..b9042ca6c21 100755
--- a/htdocs/salaries/card.php
+++ b/htdocs/salaries/card.php
@@ -492,7 +492,7 @@ if ($action == 'create') {
// Bank
if (!empty($conf->banque->enabled)) {
print '
| ';
- print $form->editfieldkey('BankAccount', 'selectaccountid', '', $object, 0, 'string', '', 1).' | ';
+ print $form->editfieldkey('DefaultBankAccount', 'selectaccountid', '', $object, 0, 'string', '', 1).' | ';
print img_picto('', 'bank_account', 'class="paddingrighonly"');
$form->select_comptes($accountid, "accountid", 0, '', 1); // Affiche liste des comptes courant
print ' |
';
@@ -500,7 +500,7 @@ if ($action == 'create') {
// Type payment
print '| ';
- print $form->editfieldkey('PaymentMode', 'selectpaymenttype', '', $object, 0, 'string', '', 1).' | ';
+ print $form->editfieldkey('DefaultPaymentMode', 'selectpaymenttype', '', $object, 0, 'string', '', 1).' | ';
$form->select_types_paiements(GETPOST("paymenttype", 'aZ09'), "paymenttype", '');
print ' |
';
@@ -687,12 +687,12 @@ if ($id) {
print '';
if ($action == 'edit') {
- print '| '.$langs->trans("DateStartPeriod")." | ";
+ print ' |
| '.$langs->trans("DateStartPeriod")." | ";
print $form->selectDate($object->datesp, 'datesp', 0, 0, 0, 'datesp', 1);
print " |
";
} else {
print "";
- print '| ' . $langs->trans("DateStartPeriod") . ' | ';
+ print ' | ' . $langs->trans("DateStartPeriod") . ' | ';
print dol_print_date($object->datesp, 'day');
print ' |
';
}
@@ -723,10 +723,10 @@ if ($id) {
print '| ' . $langs->trans("Amount") . ' | ' . price($object->amount, 0, $outputlangs, 1, -1, -1, $conf->currency) . ' |
';
}
// Mode of payment
print '';
print '| ';
- print $langs->trans('PaymentMode');
+ print $langs->trans('DefaultPaymentMode');
print ' | ';
if ($action != 'editmode')
print 'id.'">'.img_edit($langs->trans('SetMode'), 1).' | ';
@@ -740,11 +740,11 @@ if ($id) {
}
print ' ';
- // Bank Account
+ // Default Bank Account
if (!empty($conf->banque->enabled)) {
print '';
print '| ';
- print $langs->trans('BankAccount');
+ print $langs->trans('DefaultBankAccount');
print ' | ';
if ($action != 'editbankaccount' && $user->rights->salaries->write) {
print ' | id.'">'.img_edit($langs->trans('SetBankAccount'), 1).' | ';
@@ -723,10 +723,10 @@ if ($id) {
';
}
- // Mode of payment
+ // Default mode of payment
print '';
print '| ';